Crate ferrox_validation

Crate ferrox_validation 

Re-exports

pub use extractor::ValidatedJson;

Modules

extractor

Structs

ValidationError
ValidationErrors

Traits

Validate
This is the original trait that was implemented by deriving Validate. It will still be implemented for struct validations that don’t take custom arguments. The call is being forwarded to the ValidateArgs<'v_a> trait.

Functions

setup

Derive Macros

Validate