Re-exports
pub use extractor::ValidatedJson;
Modules
Structs
Traits
- Validate
- This is the original trait that was implemented by deriving
Validate. It will still be implemented for struct validations that don’t take custom arguments. The call is being forwarded to theValidateArgs<'v_a>trait.