Structs
- Validated
Json - ValidatedJson is an Axum extractor that behaves like Zod’s
.parse(). It consumes the request body as JSON, parses it into type T, and immediately calls.validate()on it. If validation fails, it throws a formatted 400 Bad Request error.